@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import sys
+
 from cliff.command import Command
 
 from kolla_ansible import ansible
@@ -63,6 +65,14 @@ class KollaAnsibleMixin:
         return verbosity_args
 
     def run_playbooks(self, parsed_args, *args, **kwargs):
+        # If the user knows what they're doing and explicitly sets
+        # ansible_python_interpreter, respect their choice and avoid
+        # overriding it by kolla-ansible.
+        extra = kwargs.get("extra_vars", {})
+        for var in getattr(parsed_args, "extra_vars", []) or []:
+            if var.startswith("ansible_python_interpreter="):
+                extra.pop("ansible_python_interpreter", None)
+                break
         kwargs.update(self._get_verbosity_args())
         return ansible.run_playbooks(parsed_args, *args, **kwargs)
 
@@ -153,6 +163,7 @@ class BootstrapServers(KollaAnsibleMixin, Command):
 
         extra_vars = {}
         extra_vars["kolla_action"] = "bootstrap-servers"
+        extra_vars["ansible_python_interpreter"] = "auto_silent"
 
         playbooks = _choose_playbooks(parsed_args, "kolla-host")
 
@@ -199,7 +210,9 @@ class OctaviaCertificates(KollaAnsibleMixin, Command):
         return parser
 
     def take_action(self, parsed_args):
-        extra_vars = {}
+        extra_vars = {
+            "ansible_python_interpreter": sys.executable
+        }
 
         if hasattr(parsed_args, "check_expiry") \
                 and parsed_args.check_expiry is not None:
@@ -281,6 +294,11 @@ class Stop(KollaAnsibleMixin, Command):
             required=True,
             help="WARNING! This action will remove the Openstack deployment!",
         )
+        group.add_argument(
+            "--ignore-missing",
+            action="store_true",
+            help="Don't fail if there are missing containers"
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -288,6 +306,9 @@ class Stop(KollaAnsibleMixin, Command):
 
         extra_vars = {}
         extra_vars["kolla_action"] = "stop"
+        extra_vars["kolla_action_stop_ignore_missing"] = (
+            "yes" if parsed_args.ignore_missing else "no"
+        )
 
         playbooks = _choose_playbooks(parsed_args)
 
@@ -469,3 +490,30 @@ class NovaLibvirtCleanup(KollaAnsibleMixin, Command):
         playbooks = _choose_playbooks(parsed_args, "nova-libvirt-cleanup")
 
         self.run_playbooks(parsed_args, playbooks)
+
+
+class Check(KollaAnsibleMixin, Command):
+    """Check container status"""
+
+    def take_action(self, parsed_args):
+        self.app.LOG.info("Checking container status")
+
+        extra_vars = {}
+        extra_vars["kolla_action"] = "check"
+
+        playbooks = _choose_playbooks(parsed_args)
+
+        self.run_playbooks(parsed_args, playbooks, extra_vars=extra_vars)
+
+
+class MigrateContainerEngine(KollaAnsibleMixin, Command):
+    """Migrate the container engine of the deployed OpenStack"""
+
+    def take_action(self, parsed_args):
+        self.app.LOG.info(
+            "Migrate the container engine of the deployed Openstack"
+        )
+
+        playbooks = _choose_playbooks(parsed_args, "migrate-container-engine")
+
+        self.run_playbooks(parsed_args, playbooks)
