@@ -167,7 +167,7 @@ function create_instance {
         server_create_extra="${server_create_extra} --config-drive True"
     fi
 
-    openstack server create --wait --image cirros --flavor m1.tiny --key-name mykey --network demo-net ${server_create_extra} ${name}
+    openstack server create --wait --image cirros --flavor c1.tiny --key-name mykey --network demo-net ${server_create_extra} ${name}
     # If the status is not ACTIVE, print info and exit 1
     if [[ $(openstack server show ${name} -f value -c status) != "ACTIVE" ]]; then
         echo "FAILED: Instance is not active"
@@ -179,13 +179,7 @@ function create_instance {
 function resize_instance {
     local name=$1
 
-    # TODO(priteau): Remove once previous_release includes m2.tiny in
-    # init-runonce
-    if ! openstack flavor list -f value | grep m2.tiny; then
-        openstack flavor create --id 6 --ram 512 --disk 1 --vcpus 2 m2.tiny
-    fi
-
-    openstack server resize --flavor m2.tiny --wait ${name}
+    openstack server resize --flavor c2.tiny --wait ${name}
     # If the status is not VERIFY_RESIZE, print info and exit 1
     if [[ $(openstack server show ${name} -f value -c status) != "VERIFY_RESIZE" ]]; then
         echo "FAILED: Instance is not resized"
@@ -197,16 +191,17 @@ function resize_instance {
 
     # Confirming the resize operation is not instantaneous. Wait for change to
     # be reflected in server status.
+    local attempt
     attempt=1
     while [[ $(openstack server show ${name} -f value -c status) != "ACTIVE" ]]; do
         echo "Instance is not active yet"
         attempt=$((attempt+1))
-        if [[ $attempt -eq 5 ]]; then
+        if [[ $attempt -eq 10 ]]; then
             echo "FAILED: Instance failed to become active after resize confirm"
             openstack --debug server show ${name}
             return 1
         fi
-        sleep 2
+        sleep 10
     done
 }
 
@@ -267,7 +262,7 @@ function test_ssh {
     local instance_name=$1
     local fip_addr=$2
     local attempts
-    attempts=12
+    attempts=30
     for i in $(seq 1 ${attempts}); do
         if ping -c1 -W1 ${fip_addr} && ssh -v -o BatchMode=yes -o StrictHostKeyChecking=no cirros@${fip_addr} hostname; then
             break
@@ -444,7 +439,7 @@ function test_internal_dns_integration {
         SERVER_NAME="my_vm"
         SERVER_NAME_SANITIZED=$(echo ${SERVER_NAME} | sed -e 's/_/-/g')
 
-        openstack server create --image cirros --flavor m1.tiny --network dns-test-network ${SERVER_NAME}
+        openstack server create --image cirros --flavor c1.tiny --network dns-test-network ${SERVER_NAME}
 
         SERVER_ID=$(openstack server show ${SERVER_NAME} -f value -c id)
         attempt=0
@@ -487,6 +482,19 @@ function test_internal_dns_integration {
     fi
 }
 
+function test_proxysql_prometheus_exporter {
+    if [[ $SCENARIO == "cells" ]]; then
+        if curl -v http://127.0.0.1:6070/metrics 2>/dev/null | grep '^proxysql_'; then
+            echo "[i] Proxysql prometheus exporter - PASS"
+            mkdir -p /tmp/logs/prometheus-exporters/proxysql
+            curl -v http://127.0.0.1:6070/metrics 2>/dev/null -o /tmp/logs/prometheus-exporters/proxysql/exporter.txt
+        else
+            echo "[e] Proxysql prometheus exporter - FAIL"
+            exit 1
+        fi
+    fi
+}
+
 function test_openstack_logged {
     . /etc/kolla/admin-openrc.sh
     . ~/openstackclient-venv/bin/activate
@@ -494,6 +502,7 @@ function test_openstack_logged {
     test_neutron_modules
     test_instance_boot
     test_internal_dns_integration
+    test_proxysql_prometheus_exporter
 
     # Check for x86_64 architecture to run q35 tests
     if [[ $(uname -m) == "x86_64" ]]; then
